==> odoo8_addon_website_event_register_free_with_sale-8.0.1.0.0.99.dev10-py2-none-any.whl: odoo_addons/website_event_register_free_with_sale/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    Copyright (c) 2015 Serv. Tecnol. Avanzados (http://www.serviciosbaeza.com)
#                       Pedro M. Baeza <pedro.baeza@serviciosbaeza.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
{
    "name": "Register for free events - Sale extension",
    "version": "8.0.1.0.0",
    "author": "Serv. Tecnol. Avanzados - Pedro M. Baeza, "
              "Antiun Ingeniería S.L.,",
              "Odoo Community Association (OCA)"
    "license": "AGPL-3",
    "category": "Website",
    "summary": "Combine free and paid tickets on events",
    "depends": [
        'website_event_register_free',
        'website_event_sale',
    ],
    "auto_install": True,
    "installable": True,
}

==> odoo8_addon_website_event_register_free_with_sale-8.0.1.1.0.99.dev1-py2-none-any.whl: odoo_addons/website_event_register_free_with_sale/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    Copyright (c) 2015 Serv. Tecnol. Avanzados (http://www.serviciosbaeza.com)
#                       Pedro M. Baeza <pedro.baeza@serviciosbaeza.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
{
    "name": "Register for free events - Sale extension",
    "version": "8.0.1.1.0",
    "author": "Tecnativa, "
              "Antiun Ingeniería S.L., "
              "Odoo Community Association (OCA)",
    "website": "https://www.tecnativa.com",
    "license": "AGPL-3",
    "category": "Website",
    "summary": "Combine free and paid tickets on events",
    "depends": [
        'website_event_register_free',
        'website_event_sale',
    ],
    "data": [
        "templates/website_sale.xml",
    ],
    "auto_install": True,
    "installable": True,
}
